const declare = require('@babel/helper-plugin-utils');

module.exports = declare((api, { react, typescript, ...others={} }) => {
  api.assertVersion(7);
  const {
    loose = false,
    targets = { browsers: ['last 2 versions'] },
    env = {},
  } = others;

  if (typeof react !== "boolean") {
    throw new Error(".react must be a boolean, or undefined");
  }
  if (typeof typescript !== "boolean") {
    throw new Error(".typescript must be a boolean, or undefined");
  }
  const plugins = [
    require.resolve('@babel/plugin-transform-runtime'),
    [require.resolve('@babel/plugin-proposal-decorators'), { legacy: true }],
    [require.resolve('@babel/plugin-proposal-class-properties'), { loose: true }],
    require.resolve('@babel/plugin-proposal-object-rest-spread'),
    require.resolve('@babel/plugin-syntax-dynamic-import'),
  ];

  const presets = [];

  if (typescript) presets.push(require.resolve('@babel/preset-env'));

  presets.push([
    require.resolve('@babel/preset-env'),
    {
      targets,
      loose,
      modules: 'commonjs',
      ...env,
    },
  ]);

  if (react) presets.push(require.resolve('@babel/preset-react'));


  return {
    presets,
    plugins
  }
})
